@@ -21,7 +21,7 @@
 #include "MainWindow.h"
 
 // Qt
-#include <QtGui/QVBoxLayout>
+#include <QVBoxLayout>
 
 // KDE
 #include <KAcceleratorManager>
@@ -61,7 +61,7 @@ using namespace Konsole;
 /* Normally it would be enough to just have this determined via the window
    manager. But there exist GPU drivers (NVIDIA) that have serious performance
    issues if transparency is enbled inside Konsole. The rest of the system
-   works fine. NVIDIA users might want to use --notransparency to work 
+   works fine. NVIDIA users might want to use --notransparency to work
    around such issues. */
 static bool useTransparency()
 {
@@ -538,7 +538,7 @@ bool MainWindow::queryClose()
 
     // make sure the window is shown on current desktop and is not minimized
     KWindowSystem::setOnDesktop(winId(), KWindowSystem::currentDesktop());
-    if ( isMinimized() ) {
+    if (isMinimized()) {
         KWindowSystem::unminimizeWindow(winId(), true);
     }
 
